@@ -14,7 +14,7 @@ __version__ = importlib_metadata.version(__name__)
 from . import utilities
 from .utilities import (
     file_format, sxs_directory, read_config, write_config, sxs_id, lev_number,
-    jit, vectorize, guvectorize
+    jit, vectorize, guvectorize, version_info
 )
 from .time_series import TimeSeries
 from .metadata import Metadata
@@ -22,7 +22,8 @@ from .catalog import Catalog
 from .horizons import Horizons, HorizonQuantities
 from .waveforms import WaveformModes #, WaveformGrid, WaveformSignal
 from .waveforms import rotating_paired_xor_multishuffle_bzip2 as rpxmb
-from . import catalog, metadata, horizons, waveforms, zenodo
+from .waveforms import rotating_paired_diff_multishuffle_bzip2 as rpdmb
+from . import catalog, metadata, horizons, waveforms, zenodo, caltechdata
 from .handlers import load, loadcontext
 
 # The speed of light is, of course, defined to be exactly
