@@ -1,3 +1,10 @@
+"""Class encapsulating "deposit" objects on Zenodo
+
+Also called "depositions", these are only accessible to the user who creates
+them.  Thus, you need the correct login information to access a deposit.
+
+"""
+
 class Deposit(object):
 
     def __init__(self, login, deposition_id=None, ignore_deletion=False):
@@ -7,7 +14,7 @@ class Deposit(object):
         updating, or replacing an entry in zenodo.
 
         Parameters
-        ==========
+        ----------
         login: Login object
             Object containing a `requests.Session` object that can successfully interact with the
             Zenodo API.  See the help string for `Login` in this module.
@@ -298,7 +305,7 @@ class Deposit(object):
 
 
         Metadata keys and allowed values
-        ================================
+        --------------------------------
         title: string, required
 
         creators: list of dictionaries, required
@@ -642,7 +649,7 @@ class Deposit(object):
         they match, the upload is skipped and `None` is returned.
 
         Parameters
-        ==========
+        ----------
         path: string
             Relative or absolute path to the file to upload
         name: string or None [default: None]
@@ -732,8 +739,6 @@ class Deposit(object):
         function.
 
         """
-        import os
-        import re
         from ...utilities import find_files
         paths_and_names = find_files(top_directory, exclude=exclude)
         for path, name in paths_and_names:
